flutter_skeleton_loader library

Classes

AvatarSkeleton
BaseSkeleton
ButtonSkeleton
CardSkeleton
CheckboxSkeleton
CircleAvatarSkeleton
ContainerSkeleton
IconButtonSkeleton
IconSkeleton
ImageSkeleton
ListSkeleton
ListTileSkeleton
ListViewSkeleton
OptimizedSkeletonRegistry
OptimizedSkeletonRegistry Registry for optimized skeleton loading
PageViewSkeleton
RadioSkeleton
SizedBoxSkeleton
SkeletonConfig
SkeletonConfig global configuration for SkeletonLoader that allows you to set values by default for the entire application, reducing the need to pass the same parameters repeatedly.
SkeletonLoader
SkeletonLoader wraps any Flutter widget and automatically creates a skeleton version of it when isLoading is true. When the data is ready, it smoothly transitions to show the actual content.
SkeletonLoaderBuilder
SkeletonLoaderBuilderBuilder pattern to create SkeletonLoader with fluent syntax and configuration more intuitive. Reduces verbosity and improves developer experience.
SkeletonProvider
SkeletonProvider interface for skeleton providers that defines the contract that all specific skeleton generators must adhere to.
SliderSkeleton
SwitchSkeleton
TabBarSkeleton
TextFieldSkeleton
TextSkeleton
WidgetValidator
WidgetValidator Utility to validate and sanitize widgets before converting them to skeletons. Prevents common errors such as infinite dimensions, overflow, and problematic configurations that can cause rendering exceptions.