SkeletonProvider class abstract
SkeletonProvider interface for skeleton providers that defines the contract that all specific skeleton generators must adhere to.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- priority → int
-
PRIORITYDefines the priority of this provider Providers with higher priority are evaluated first Default is 0 (normal priority)no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canHandle(
Widget widget) → bool -
VALIDATIONDetermines if this provider can handle the given widget -
createSkeleton(
Widget originalWidget, Color baseColor) → Widget -
SKELETON GENERATIONCreates the corresponding skeleton -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited